==> ibridges-0.2.4.tar.gz: ibridges-0.2.4/docker/irods_client/tests/test_meta.py <==
import irods
import pytest
from pytest import mark

from ibridges.export_metadata import export_metadata_to_dict
from ibridges.meta import MetaData


@mark.parametrize("item_name", ["collection", "dataobject"])
def test_meta(item_name, request):
    item = request.getfixturevalue(item_name)
    meta = MetaData(item)
    meta.clear()

    assert len(str(meta)) == 0
    assert len(list(meta)) == 0

    # Add key, value pair
    meta.add("x", "y")
    assert len(list(meta)) == 1
    assert list(meta)[0].name == "x"
    assert list(meta)[0].value == "y"
    assert list(meta)[0].units is None
    assert "x" in meta
    assert ("x", "y") in meta
    assert "y" not in meta
    assert ("x", "z") not in meta
    assert ("x", "y", "z") not in meta

    # Same key, but different value
    meta.add("x", "z")
    assert len(list(meta)) == 2
    assert len(str(meta).split("\n")) == 3  #\n at the end
    assert ("x", "z") in meta

    # Same key, value different units
    meta.add("x", "z", "m")
    assert len(list(meta)) == 3
    assert ("x", "z", "m") in meta

    # Test that we cannot add the same metadata twice
    with pytest.raises(ValueError):
        meta.add("x", "y")
    with pytest.raises(ValueError):
        meta.add("x", "z", "m")

    # Cannot delete value with different units
    assert ("x", "z", "kg") not in meta
    with pytest.raises(KeyError):
        meta.delete("x", "z", "kg")
    meta.delete("x", "z", "m")
    assert len(list(meta)) == 2

    meta.delete("x", "z")
    assert len(list(meta)) == 1

    meta.delete("x", None)
    assert len(list(meta)) == 0

    meta.add("x", "y")
    meta.add("y", "z")
    meta.set("y", "x")
    assert "x" in meta
    assert ("y", "z") not in meta
    assert ("y", "x") in meta

@mark.parametrize("item_name", ["collection", "dataobject"])
def test_metadata_todict(item_name, request):
    item = request.getfixturevalue(item_name)
    meta = MetaData(item)
    meta.clear()
    # test against:
    test_dict = {
            'name': item.name,
            'irods_id': item.id,
            'metadata': [('x', 'z', 'm')]
            }

    if isinstance(item, irods.data_object.iRODSDataObject):
        test_dict['checksum'] = item.checksum

    # Add some metadata
    meta.add("x", "z", "m")
    assert "x" in meta
    result = meta.to_dict()

    for key in result.keys():
        assert key in test_dict
    for value in result.values():
        assert value in test_dict.values()

@mark.parametrize("item_name", ["collection", "dataobject"])
def test_metadata_export(item_name, request, session):
    item = request.getfixturevalue(item_name)
    res = export_metadata_to_dict(MetaData(item), session)
    assert isinstance(res, dict)

==> ibridges-1.0.1.tar.gz: ibridges-1.0.1/docker/irods_client/tests/test_meta.py <==
import json

import irods
import pytest
from pytest import mark

from ibridges.data_operations import Operations
from ibridges.meta import MetaData
from ibridges.path import IrodsPath


@mark.parametrize("item_name", ["collection", "dataobject"])
def test_meta(item_name, request):
    item = request.getfixturevalue(item_name)
    meta = MetaData(item)
    meta.clear()

    assert len(str(meta)) == 0
    assert len(meta) == 0

    # Add key, value pair
    meta.add("x", "y")
    assert len(meta) == 1
    assert list(meta)[0].name == "x"
    assert list(meta)[0].value == "y"
    assert list(meta)[0].units is None
    assert "x" in meta
    assert ("x", "y") in meta
    assert "y" not in meta
    assert ("x", "z") not in meta
    assert ("x", "y", "z") not in meta

    # Same key, but different value
    meta.add("x", "z")
    assert len(meta) == 2
    assert len(str(meta).split("\n")) == 2
    assert ("x", "z") in meta

    # Same key, value different units
    meta.add("x", "z", "m")
    assert len(meta) == 3
    assert ("x", "z", "m") in meta

    # Test that we cannot add the same metadata twice
    with pytest.raises(ValueError):
        meta.add("x", "y")
    with pytest.raises(ValueError):
        meta.add("x", "z", "m")

    # Cannot delete value with different units
    assert ("x", "z", "kg") not in meta
    with pytest.raises(KeyError):
        meta.delete("x", "z", "kg")
    meta.delete("x", "z", "m")
    assert len(meta) == 2

    meta.delete("x", "z")
    assert len(meta) == 1

    meta.delete("x")
    assert len(meta) == 0

    meta.add("x", "y")
    meta.add("y", "z")
    meta.set("y", "x")
    assert "x" in meta
    assert ("y", "z") not in meta
    assert ("y", "x") in meta

@mark.parametrize("item_name", ["collection", "dataobject"])
def test_metadata_todict(item_name, request):
    item = request.getfixturevalue(item_name)
    meta = MetaData(item)
    meta.clear()
    # test against:
    test_dict = {
            'name': item.name,
            'irods_id': item.id,
            'metadata': [('x', 'z', 'm')]
            }

    if isinstance(item, irods.data_object.iRODSDataObject):
        test_dict['checksum'] = item.checksum

    # Add some metadata
    meta.add("x", "z", "m")
    assert "x" in meta
    result = meta.to_dict()

    for key in result.keys():
        assert key in test_dict
    for value in result.values():
        assert value in test_dict.values()

@mark.parametrize("item_name", ["collection", "dataobject"])
def test_metadata_export(item_name, request, session, tmpdir):
    tmp_file = tmpdir/"meta.json"
    item = request.getfixturevalue(item_name)
    meta_dict = MetaData(item).to_dict()
    assert isinstance(meta_dict, dict)
    assert "name" in meta_dict
    assert "irods_id" in meta_dict
    assert "metadata" in meta_dict

    ops = Operations()
    ops.add_meta_download(IrodsPath(session, item.path), IrodsPath(session, item.path), tmp_file)
    ops.execute(session)
    with open(tmp_file, "r", encoding="utf-8"):
        new_meta_dict = json.load(tmp_file)
    assert isinstance(new_meta_dict, dict)
